package com.nisum.omd;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ThreadLocalRandom;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;
import com.nisum.omd.domain.Order;
import com.nisum.omd.service.OmdProducerService;
import com.nisum.omd.service.RandomDataGenerator;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
@Component
@RestController
public class OrderGenerator {
	private static final Logger logger = LogManager.getLogger(OrderGenerator.class);
	@Autowired
	private RandomDataGenerator randomDataGenerator;
	@Autowired
	private Order order;
	@Autowired
	private OmdProducerService omdProducerService;

	private Boolean orderGenerateFlag =  false;
	private List<Double> intervalList;
	
	public Boolean getOrderGenerateFlag() {
		return orderGenerateFlag;
	}

	public void setOrderGenerateFlag(Boolean orderGenerateFlag) {
		this.orderGenerateFlag = orderGenerateFlag;
	}
	
	public void execute() throws Exception {
		  intervalList = randomDataGenerator.generateIntervals();
		  while(true) {
			  if (orderGenerateFlag) {
				  order = getObjectData(order);
				  omdProducerService.sendMessage(order);
				  ObjectMapper objectMapper = new ObjectMapper();
				  objectMapper.registerModule(new JavaTimeModule());
				  objectMapper.disable(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS);
				  String jsonOrderStr = objectMapper.writeValueAsString(order);	
				  logger.info(jsonOrderStr);
				  Thread.sleep((long)(getRandomInterval(intervalList) * 1000));
			  }
		  }
	}
	@GetMapping(path="/orderStartStop/{gneratorFlag}")
	public String orderStartStop(@PathVariable("gneratorFlag")boolean gneratorFlag) throws Exception{
		    orderGenerateFlag = gneratorFlag;
		    if (orderGenerateFlag) {
		    	CompletableFuture.runAsync(() -> {
					try {
						execute();
					} catch (Exception e) {
						e.printStackTrace();
					}
				});
		    }
			return "Order Generate : " + orderGenerateFlag.toString();
		}
	
	private Order getObjectData(Order orders) {
		LocalDateTime currentTime = LocalDateTime.now();
		Date currentDateTime = Date.from(currentTime.atZone( ZoneId.systemDefault()).toInstant());

    	order.setOrderNum(randomDataGenerator.generateOrderNumber());
		order.setCustomerId(randomDataGenerator.generateCustomerId());
	//	DateTimeFormatter formatter = DateTimeFormatter.ISO_DATE_TIME;
	//	String formattedDateTime = currentTime.format(formatter);
		order.setOrderDate(currentDateTime);
		order.setLineItem(randomDataGenerator.genetateLineItem(order.getLineItem()));
        return order;
	}
	
	private  static Double getRandomInterval(List<Double> list) {
	    int index = ThreadLocalRandom.current().nextInt(list.size());
	    return list.get(index);

	}


}
