package com.nisum.omd.service;

import com.nisum.omd.domain.Order;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.support.SendResult;
import org.springframework.stereotype.Service;
import org.springframework.util.concurrent.ListenableFuture;
import org.springframework.util.concurrent.ListenableFutureCallback;

@Service
public class OmdProducerService {

    @Autowired
    private KafkaTemplate<String, Order> kafkaTemplate;

    @Value("${topic-name}")
    private String topic;

    private Logger logger = LoggerFactory.getLogger(OmdProducerService.class);

    public void sendMessage(Order order) {
        ListenableFuture<SendResult<String, Order>> future =
                kafkaTemplate.send(topic, order);
        future.addCallback(new ListenableFutureCallback<SendResult<String, Order>>() {
            @Override
            public void onSuccess(SendResult<String, Order> result) {
                logger.info(" Published Order Data with Order Number :"
                        + order.getOrderNum() + " In Topic :"+ result.getRecordMetadata().topic());
            }
            @Override
            public void onFailure(Throwable ex) {
                logger.error("Unable to Publish the Order Data, Due to: ",ex.getMessage());
            }
        });
    }

}
