package com.nisum.omd.spark.service;

import com.nisum.omd.kafka.utility.OmdKafkaUtility;
import com.nisum.omd.kafka.connection.OmdKafkaConnection;
import com.nisum.omd.mongo.repository.OmdSparkStreamRepositoryImpl;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.spark.SparkConf;
import org.apache.spark.streaming.Duration;
import org.apache.spark.streaming.api.java.JavaInputDStream;
import org.apache.spark.streaming.api.java.JavaStreamingContext;
import org.apache.spark.streaming.kafka010.ConsumerStrategies;
import org.apache.spark.streaming.kafka010.KafkaUtils;
import org.apache.spark.streaming.kafka010.LocationStrategies;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Map;

@Service
public class OmdSparkStreamService {
    private static final Map<String, Object> KAFKA_CONSUMER_PROPERTIES;
    static {

        KAFKA_CONSUMER_PROPERTIES = Collections.unmodifiableMap(OmdKafkaConnection.kakfkaconfig());
    }

    private static final Collection<String> TOPICS =
            Collections.unmodifiableList(Arrays.asList(OmdKafkaUtility.KAFKA_TOPIC));

    public  void sparkInvokation()throws InterruptedException  {


        JavaInputDStream<ConsumerRecord<String, String>> orderStream = null;

           // System.setProperty("hadoop.home.dir", OmdKafkaUtility.HADOOP_HOME_DIR_VALUE);

            SparkConf conf = new SparkConf()
                    .setMaster(OmdKafkaUtility.RUN_LOCAL_WITH_AVAILABLE_CORES)
                    .setAppName(OmdKafkaUtility.APPLICATION_NAME)
                    .set("spark.mongodb.output.uri", OmdKafkaUtility.MONGODB_OUTPUT_URI);
            conf.set("spark.testing.memory", "2147480000");

            JavaStreamingContext streamingContext
                    = new JavaStreamingContext(conf, new Duration(OmdKafkaUtility.BATCH_DURATION_INTERVAL_MS));

            orderStream =
                    KafkaUtils.createDirectStream(
                            streamingContext,
                            LocationStrategies.PreferConsistent(),
                            ConsumerStrategies.<String, String>Subscribe(TOPICS, KAFKA_CONSUMER_PROPERTIES)
                    );
            OmdSparkStreamRepositoryImpl.saveMongoData(orderStream);
            streamingContext.start();

            streamingContext.awaitTermination();





        }

}
